@@ -19,13 +19,15 @@ pattern_headfunc=re.compile("var wqadd_headfunc = \[\];",re.MULTILINE | re.DOTAL
 pattern_tailfunc=re.compile("var wqadd_tailfunc = \[\];",re.MULTILINE | re.DOTALL)
 pattern_gpslist=re.compile(r"(?<=var marker, lineArr = ).*?(?=;$)",re.MULTILINE | re.DOTALL)
 pattern_markerlist=re.compile(r"(?<=var marker_list = ).*?(?=;$)",re.MULTILINE | re.DOTALL)
+pattern_automarker=re.compile(r"(?<=var auto_marker = ).*?(?=;$)",re.MULTILINE | re.DOTALL)
 pattern_speed=re.compile(r"(?<=var _speed = ).*?(?=;$)",re.MULTILINE | re.DOTALL)
 
 class Trajectory():
-    def __init__(self, gps_list=[], marker_list=[]):
+    def __init__(self, gps_list=[], marker_list=[], auto_marker=True):
         self.js=get_main_js()
         self.gps_str = json.dumps(gps_list)
         self.marker_str = json.dumps(marker_list)
+        self.auto_marker = str(auto_marker).lower()
         self.head_data = ''
         self.tail_data = ''
         self.head_func = ''
@@ -52,7 +54,8 @@ class Trajectory():
         _out3 = re.sub(pattern_headdata, self.head_data, _out2)
         _out4 = re.sub(pattern_taildata, self.tail_data, _out3)
         _out5 = re.sub(pattern_headfunc, self.head_func, _out4)
-        _out = re.sub(pattern_tailfunc, self.tail_func, _out5)
+        _out6 = re.sub(pattern_tailfunc, self.tail_func, _out5)
+        _out = re.sub(pattern_automarker, self.auto_marker, _out6)
         _out = re.sub(pattern_speed, str(speed), _out)
         if html_name:
             self.html_name = os.path.abspath(str(html_name)+'.html')
@@ -104,7 +107,14 @@ def get_main_js():
     <script>
         var wqadd_headdata = [];
         var marker, lineArr = [[116.478935,39.997761],[116.478939,39.997825],[116.478912,39.998549],[116.478912,39.998549],[116.478998,39.998555],[116.478998,39.998555],[116.479282,39.99856],[116.479658,39.998528],[116.480151,39.998453],[116.480784,39.998302],[116.480784,39.998302],[116.481149,39.998184],[116.481573,39.997997],[116.481863,39.997846],[116.482072,39.997718],[116.482362,39.997718],[116.483633,39.998935],[116.48367,39.998968],[116.484648,39.999861]];
-
+        if (lineArr.length<1)
+        {
+            marker_visible=false
+        }
+        else 
+        {
+            marker_visible=true
+        }
         var map = new AMap.Map("container", {
             resizeEnable: true,
             center: lineArr[0],
@@ -118,6 +128,7 @@ def get_main_js():
             offset: new AMap.Pixel(-26, -13),
             autoRotation: true,
             angle:-90,
+            visible:marker_visible,
         });
 
         // 绘制轨迹
@@ -142,6 +153,7 @@ def get_main_js():
 
         //新增标记点
         var marker_list = [[116.478935,39.997761],[116.484648,39.999861]];
+        var auto_marker = true;
         for (var i = 0; i < marker_list.length; i++) {
             var _curData = marker_list[i];
             if (_curData.length>=3)
@@ -149,8 +161,14 @@ def get_main_js():
                 cont_text=(i+1).toString()+": "+_curData[2].toString();
             }
             else
-            {
-                cont_text=(i+1).toString();
+            {   if (auto_marker)
+                {
+                    cont_text=(i+1).toString();
+                }
+                else
+                {
+                    cont_text='';
+                }     
             }
             var marker_i = new AMap.Marker({position: new AMap.LngLat(_curData[0],_curData[1]),label:{content: cont_text}});
             map.add(marker_i);
@@ -199,10 +217,7 @@ if __name__ == '__main__':
     gps_list=[[116.478935,39.997761],[116.478939,39.997825],[116.478912,39.998549],[116.478912,39.998549],[116.478998,39.998555],[116.478998,39.998555],[116.479282,39.99856],[116.479658,39.998528],[116.480151,39.998453],[116.480784,39.998302],[116.480784,39.998302],[116.481149,39.998184],[116.481573,39.997997],[116.481863,39.997846],[116.482072,39.997718],[116.482362,39.997718],[116.483633,39.998935],[116.48367,39.998968],[116.484648,39.999861]]
     marker_list=[[116.478935,39.997761],[116.484648,39.999861]]
 
-    traj = Trajectory(gps_list=gps_list,marker_list=marker_list)
-    # traj.add_jsfunc(func_js='''    function startAnimation () {
-    #     marker.moveAlong(lineArr, 2000);
-    # }''')
+    traj = Trajectory(gps_list=[],marker_list=marker_list,auto_marker=True)
     traj.building(web_open=True,speed=100)
 
 
